@@ -67,9 +67,9 @@ class TopList(Gtk.Box):
         for i, node in enumerate(nodes):
             self.liststore_nodes.append([
                 self.app.theme['anonymous'],
-                Widgets.unescape_html(node['name']),
+                Widgets.unescape(node['name']),
                 int(node['sourceid']),
-                Widgets.unescape_html(node['info']),
+                Widgets.unescape(node['info']),
                 Widgets.set_tooltip_with_song_tips(
                     node['name'], node['tips']),
                 ])
@@ -100,9 +100,9 @@ class TopList(Gtk.Box):
         for song in songs:
             self.liststore_songs.append([
                 True,
-                song['name'], 
-                song['artist'],
-                song['album'],
+                Widgets.unescape(song['name']), 
+                Widgets.unescape(song['artist']),
+                Widgets.unescape(song['album']),
                 int(song['id']), 
                 int(song['artistid']),
                 int(song['albumid']),
